@@ -43,7 +43,13 @@ from click.install import (
     ClickInstallerPermissionDenied,
 )
 from click.preinst import static_preinst
-from click.tests.helpers import TestCase, mkfile, mock, touch
+from click.tests.helpers import (
+    disable_logging,
+    mkfile,
+    mock,
+    TestCase,
+    touch,
+)
 
 
 @contextmanager
@@ -69,6 +75,12 @@ class TestClickInstaller(TestCase):
         self.use_temp_dir()
         self.db = Click.DB()
         self.db.add(self.temp_dir)
+        # mock signature checks during the tests
+        self.debsig_patcher = mock.patch("click.install.DebsigVerify")
+        self.debsig_patcher.start()
+
+    def tearDown(self):
+        self.debsig_patcher.stop()
 
     def make_fake_package(self, control_fields=None, manifest=None,
                           control_scripts=None, data_files=None):
@@ -103,16 +115,6 @@ class TestClickInstaller(TestCase):
             self.temp_dir, control_dir, data_dir, package_path)
         return package_path
 
-    def _setup_frameworks(self, preloads, frameworks_dir=None, frameworks=[]):
-        if frameworks_dir is None:
-            frameworks_dir = os.path.join(self.temp_dir, "frameworks")
-        shutil.rmtree(frameworks_dir, ignore_errors=True)
-        Click.ensuredir(frameworks_dir)
-        for framework in frameworks:
-            touch(os.path.join(frameworks_dir, "%s.framework" % framework))
-        preloads["click_get_frameworks_dir"].side_effect = (
-            lambda: self.make_string(frameworks_dir))
-
     def test_audit_no_click_version(self):
         path = self.make_fake_package()
         self.assertRaisesRegex(
@@ -236,6 +238,24 @@ class TestClickInstaller(TestCase):
                 'Framework "missing" not present on system.*',
                 ClickInstaller(self.db).audit, path)
 
+    # FIXME: we really want a unit test with a valid signature too
+    def test_audit_no_signature(self):
+        if not Click.find_on_path("debsig-verify"):
+            self.skipTest("this test needs debsig-verify")
+        path = self.make_fake_package(
+            control_fields={"Click-Version": "0.4"},
+            manifest={
+                "name": "test-package",
+                "version": "1.0",
+                "framework": "",
+            })
+        self.debsig_patcher.stop()
+        self.assertRaisesRegex(
+            ClickInstallerAuditError, "Signature verification error",
+            ClickInstaller(self.db).audit, path)
+        self.debsig_patcher.start()
+
+    @disable_logging
     def test_audit_missing_framework_force(self):
         with self.run_in_subprocess(
                 "click_get_frameworks_dir") as (enter, preloads):
@@ -436,18 +456,12 @@ class TestClickInstaller(TestCase):
         with self.run_in_subprocess(
                 "click_get_frameworks_dir") as (enter, preloads):
             enter()
-            original_call = subprocess.call
+            original_call = subprocess.check_output
 
             def call_side_effect(*args, **kwargs):
-                if "TEST_VERBOSE" in os.environ:
-                    return original_call(
-                        ["touch", os.path.join(self.temp_dir, "sentinel")],
-                        **kwargs)
-                else:
-                    with open("/dev/null", "w") as devnull:
-                        return original_call(
-                            ["touch", os.path.join(self.temp_dir, "sentinel")],
-                            stdout=devnull, stderr=devnull, **kwargs)
+                return original_call(
+                    ["touch", os.path.join(self.temp_dir, "sentinel")],
+                    **kwargs)
 
             path = self.make_fake_package(
                 control_fields={
@@ -470,7 +484,7 @@ class TestClickInstaller(TestCase):
             db.add(root)
             installer = ClickInstaller(db)
             self._setup_frameworks(preloads, frameworks=["ubuntu-sdk-13.10"])
-            with mock.patch("subprocess.call") as mock_call:
+            with mock.patch("subprocess.check_output") as mock_call:
                 mock_call.side_effect = call_side_effect
                 self.assertRaises(
                     subprocess.CalledProcessError, installer.install, path)
@@ -661,6 +675,7 @@ class TestClickInstaller(TestCase):
             self.assertTrue(
                 os.path.exists(os.path.join(root, "test-package", "current")))
 
+    @disable_logging
     def test_reinstall_preinstalled(self):
         # Attempting to reinstall a preinstalled version shouldn't actually
         # reinstall it in an overlay database (which would cause
